==> com.liferay.object.api-71.0.0-sources.jar: com/liferay/object/constants/ObjectWebKeys.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.object.constants;

/**
 * @author Jorge Ferrer
 */
public class ObjectWebKeys {

	public static final String LIST_TYPE_DEFINITION = "LIST_TYPE_DEFINITION";

	public static final String LIST_TYPE_ENTRY = "LIST_TYPE_ENTRY";

	public static final String OBJECT_ACTION = "OBJECT_ACTION";

	public static final String OBJECT_DEFINITION = "OBJECT_DEFINITION";

	public static final String OBJECT_ENTRY = "OBJECT_ENTRY";

	public static final String OBJECT_ENTRY_EXTERNAL_REFERENCE_CODE =
		"OBJECT_ENTRY_EXTERNAL_REFERENCE_CODE";

	public static final String OBJECT_ENTRY_READ_ONLY =
		"OBJECT_ENTRY_READ_ONLY";

	public static final String OBJECT_ENTRY_VALUES = "OBJECT_ENTRY_VALUES";

	public static final String OBJECT_FIELD = "OBJECT_FIELD";

	public static final String OBJECT_FIELDS = "OBJECT_FIELDS";

	public static final String OBJECT_LAYOUT = "OBJECT_LAYOUT";

	public static final String OBJECT_RELATIONSHIP = "OBJECT_RELATIONSHIP";

	public static final String OBJECT_VALIDATION = "OBJECT_VALIDATION";

	public static final String OBJECT_VIEW = "OBJECT_VIEW";

	public static final String REGULAR_OBJECT_LAYOUT_TAB =
		"REGULAR_OBJECT_LAYOUT_TAB";

}

==> com.liferay.object.api-90.0.0-sources.jar: com/liferay/object/constants/ObjectWebKeys.java <==
/**
 * SPDX-FileCopyrightText: (c) 2000 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */

package com.liferay.object.constants;

/**
 * @author Jorge Ferrer
 */
public class ObjectWebKeys {

	public static final String LIST_TYPE_DEFINITION = "LIST_TYPE_DEFINITION";

	public static final String LIST_TYPE_ENTRY = "LIST_TYPE_ENTRY";

	public static final String OBJECT_ACTION = "OBJECT_ACTION";

	public static final String OBJECT_DEFINITION = "OBJECT_DEFINITION";

	public static final String OBJECT_DEFINITIONS_DETAILS_DISPLAY_CONTEXT =
		"OBJECT_DEFINITIONS_DETAILS_DISPLAY_CONTEXT";

	public static final String OBJECT_DEFINITIONS_FIELD_DISPLAY_CONTEXT =
		"OBJECT_DEFINITIONS_FIELD_DISPLAY_CONTEXT";

	public static final String OBJECT_DEFINITIONS_RELATIONSHIP_DISPLAY_CONTEXT =
		"OBJECT_DEFINITIONS_RELATIONSHIP_DISPLAY_CONTEXT";

	public static final String OBJECT_ENTRY = "OBJECT_ENTRY";

	public static final String OBJECT_ENTRY_EXTERNAL_REFERENCE_CODE =
		"OBJECT_ENTRY_EXTERNAL_REFERENCE_CODE";

	public static final String OBJECT_ENTRY_READ_ONLY =
		"OBJECT_ENTRY_READ_ONLY";

	public static final String OBJECT_ENTRY_VALUES = "OBJECT_ENTRY_VALUES";

	public static final String OBJECT_FIELD = "OBJECT_FIELD";

	public static final String OBJECT_FIELDS = "OBJECT_FIELDS";

	public static final String OBJECT_LAYOUT = "OBJECT_LAYOUT";

	public static final String OBJECT_RELATIONSHIP = "OBJECT_RELATIONSHIP";

	public static final String OBJECT_VALIDATION = "OBJECT_VALIDATION";

	public static final String OBJECT_VIEW = "OBJECT_VIEW";

	public static final String REGULAR_OBJECT_LAYOUT_TAB =
		"REGULAR_OBJECT_LAYOUT_TAB";

}
